==> mingw-w64-starpu-1.3.7-3.src.tar.gz: starpu-1.3.7/doc/doxygen/html/search/variables_2.js <==
var searchData=
[
  ['c',['c',['../group__API__Data__Interfaces.html#ad25ad86f33897a36c7197bcf80242df4',1,'starpu_bcsr_interface::c()'],['../group__API__Performance__Model.html#ac651825cdcd22fb9e6389d73c1b4f275',1,'starpu_perfmodel_regression_model::c()']]],
  ['calibrate',['calibrate',['../group__API__Initialization__and__Termination.html#ab05d39eda9e1eef89024575fcaccef23',1,'starpu_conf']]],
  ['callback_5farg',['callback_arg',['../group__API__Codelet__And__Tasks.html#aa08e84ae3bf2e88fdb893f1e123cead8',1,'starpu_task']]],
  ['callback_5farg_5ffree',['callback_arg_free',['../group__API__Codelet__And__Tasks.html#a397c52cbdde57ee5d09b7d929989ca8b',1,'starpu_task']]],
  ['callback_5fend_5ftime',['callback_end_time',['../group__API__Profiling.html#a3296b9aa5339bf99f00f5377517c2390',1,'starpu_profiling_task_info']]],
  ['callback_5ffunc',['callback_func',['../group__API__Codelet__And__Tasks.html#a03361fd33500d78c065bbe18d4626a7a',1,'starpu_task']]],
  ['callback_5fstart_5ftime',['callback_start_time',['../group__API__Profiling.html#a4ad1ae7ed15ea7001b5dc8e1d9579235',1,'starpu_profiling_task_info']]],
  ['can_5fcopy',['can_copy',['../group__API__Data__Interfaces.html#a0f4028f4d2e56725de028c90696b1f7e',1,'starpu_data_copy_methods']]],
  ['can_5fexecute',['can_execute',['../group__API__Codelet__And__Tasks.html#a29800b6f7f322a5365cfdca266f421a7',1,'starpu_codelet']]],
  ['can_5fpull',['can_pull',['../group__API__Modularized__Scheduler.html#a4c7d5c03e2acf93fa737540b35eb1001',1,'starpu_sched_component']]],
  ['can_5fpush',['can_push',['../group__API__Modularized__Scheduler.html#abf315d3c1f60fbcab6a001f7925dc4fa',1,'starpu_sched_component']]],
  ['catch_5fsignals',['catch_signals',['../group__API__Initialization__and__Termination.html#ae11cad1ceafab919d348de1f00b044d1',1,'starpu_conf']]],
  ['checked',['checked',['../group__API__Codelet__And__Tasks.html#a18eb7e68348b41db1818e8307e03d5be',1,'starpu_codelet']]],
  ['children',['children',['../group__API__Modularized__Scheduler.html#a6979a86b074eb35903929f98272b2ab2',1,'starpu_sched_component']]],
  ['cl',['cl',['../group__API__OpenMP__Runtime__Support.html#a983c8209cef872e2798c2fee32012195',1,'starpu_omp_parallel_region_attr::cl()'],['../group__API__OpenMP__Runtime__Support.html#a4f4e595f12101bbace47d4748d6d3e3b',1,'starpu_omp_task_region_attr::cl()'],['../group__API__Codelet__And__Tasks.html#ac0e8ab897e436b244f13ec17b1191062',1,'starpu_task::cl()'],['../group__API__SC__Hypervisor.html#aea7e98763fa2b2f5553cc73bf29705f7',1,'sc_hypervisor_policy_task_pool::cl()']]],
  ['cl_5farg',['cl_arg',['../group__API__OpenMP__Runtime__Support.html#acd7ec3b07eded637a0c9de5df3192e87',1,'starpu_omp_parallel_region_attr::cl_arg()'],['../group__API__OpenMP__Runtime__Support.html#ad7d88a7759aade7ae379a88eb737993b',1,'starpu_omp_task_region_attr::cl_arg()'],['../group__API__Codelet__And__Tasks.html#a1d6f3af0eab3a339c550a5a55fbd7ab2',1,'starpu_task::cl_arg()']]],
  ['cl_5farg_5ffree',['cl_arg_free',['../group__API__OpenMP__Runtime__Support.html#aea66f9b4181afb2e4b4c799a09d8a4f0',1,'starpu_omp_parallel_region_attr::cl_arg_free()'],['../group__API__OpenMP__Runtime__Support.html#ad64a8be227ee0a2c4ea8fa2eca3d20c0',1,'starpu_omp_task_region_attr::cl_arg_free()'],['../group__API__Codelet__And__Tasks.html#a3da11609ab9c508bb753cae1b2d8f24f',1,'starpu_task::cl_arg_free()']]],
  ['cl_5farg_5fsize',['cl_arg_size',['../group__API__OpenMP__Runtime__Support.html#ab804599e2d1ce232830954dbdf3ed886',1,'starpu_omp_parallel_region_attr::cl_arg_size()'],['../group__API__OpenMP__Runtime__Support.html#a594489c9f845922d685046c25f5540e8',1,'starpu_omp_task_region_attr::cl_arg_size()'],['../group__API__Codelet__And__Tasks.html#adac9af88fed23241fc65259712352126',1,'starpu_task::cl_arg_size()']]],
  ['close',['close',['../group__API__Out__Of__Core.html#a00b4fbe01a33b0f2526bd70e8128dfbd',1,'starpu_disk_ops']]],
  ['coeff',['coeff',['../group__API__Performance__Model.html#aec35b7054c3d28730425f47c61b8a297',1,'starpu_perfmodel_regression_model']]],
  ['colind',['colind',['../group__API__Data__Interfaces.html#a41630100e7fb39af8bec44fd57a559c0',1,'starpu_csr_interface::colind()'],['../group__API__Data__Interfaces.html#a52dd5cb526a5a1114b2c6737e9da7d1c',1,'starpu_bcsr_interface::colind()']]],
  ['color',['color',['../group__API__Codelet__And__Tasks.html#ad6dfcbb8bb86ca8ce0678b4b10bf853b',1,'starpu_codelet::color()'],['../group__API__Codelet__And__Tasks.html#ab96604deeb87e2924df311c9b5a7d303',1,'starpu_task::color()']]],
  ['columns',['columns',['../group__API__Data__Interfaces.html#ac01fd0c59e0a5740ab8b000a2681f0aa',1,'starpu_coo_interface']]],
  ['combinations',['combinations',['../group__API__Performance__Model.html#a4fc15e27386dcbfbe0bba81f917ce198',1,'starpu_perfmodel']]],
  ['compare',['compare',['../group__API__Data__Interfaces.html#a79dbc0a279510b9daacfa82248cc3f09',1,'starpu_data_interface_ops']]],
  ['compute_5fidle',['compute_idle',['../sc__hypervisor__monitoring_8h.html#abf552a3af2c6928c9f4e0dd6e845c7e0',1,'sc_hypervisor_wrapper']]],
  ['compute_5fpartial_5fidle',['compute_partial_idle',['../sc__hypervisor__monitoring_8h.html#a1e0e2c4e5a03176a09fe4f84a4b5a1ee',1,'sc_hypervisor_wrapper']]],
  ['config',['config',['../sc__hypervisor__monitoring_8h.html#a7ed3efcd3b7e2886f5610e5f5920eb99',1,'sc_hypervisor_wrapper']]],
  ['consider_5fmax',['consider_max',['../sc__hypervisor__monitoring_8h.html#ae60f91b9b83b82c3dd6ef43e7c8d730d',1,'sc_hypervisor_wrapper']]],
  ['copy',['copy',['../group__API__Out__Of__Core.html#a841756a748f25860e45e12e215249683',1,'starpu_disk_ops']]],
  ['copy_5fmethods',['copy_methods',['../group__API__Data__Interfaces.html#afd365e7e0abc01f07b6d7b9201c4ce22',1,'starpu_data_interface_ops']]],
  ['cost_5ffunction',['cost_function',['../group__API__Performance__Model.html#a13f34a1532294c101254beb106f124f3',1,'starpu_perfmodel_per_arch::cost_function()'],['../group__API__Performance__Model.html#a16967b7c8c6860d283fc7db434cd3c7c',1,'starpu_perfmodel::cost_function()']]],
  ['cpu_5felemsize',['cpu_elemsize',['../group__API__Data__Interfaces.html#a67a1f3202dfc2512ed7ed14bed4f3623',1,'starpu_multiformat_data_interface_ops']]],
  ['cpu_5ffunc',['cpu_func',['../group__API__Codelet__And__Tasks.html#ad5f00ed5a0a59b72c0d90d9718376893',1,'starpu_codelet']]],
  ['cpu_5ffuncs',['cpu_funcs',['../group__API__Codelet__And__Tasks.html#a593418a8961318e4085177abeeaa43ad',1,'starpu_codelet']]],
  ['cpu_5ffuncs_5fname',['cpu_funcs_name',['../group__API__Codelet__And__Tasks.html#abfc0aa8247673ad1c629d5ddd30082a3',1,'starpu_codelet']]],
  ['cpu_5fto_5fcuda_5fcl',['cpu_to_cuda_cl',['../group__API__Data__Interfaces.html#aab231ea3b842e030917eb2b67e9439eb',1,'starpu_multiformat_data_interface_ops']]],
  ['cpu_5fto_5fmic_5fcl',['cpu_to_mic_cl',['../group__API__Data__Interfaces.html#adc3e56ba90f959e6aec093ba0fa3d385',1,'starpu_multiformat_data_interface_ops']]],
  ['cpu_5fto_5fopencl_5fcl',['cpu_to_opencl_cl',['../group__API__Data__Interfaces.html#ac1103b46f4f50af4aeaa2772b3662cb2',1,'starpu_multiformat_data_interface_ops']]],
  ['cuda_5felemsize',['cuda_elemsize',['../group__API__Data__Interfaces.html#a00927819b3899892ec152968efe0b158',1,'starpu_multiformat_data_interface_ops']]],
  ['cuda_5fflags',['cuda_flags',['../group__API__Codelet__And__Tasks.html#aaa458493da38622be2713700f3c96a5d',1,'starpu_codelet']]],
  ['cuda_5ffunc',['cuda_func',['../group__API__Codelet__And__Tasks.html#a3d895b523ca1bf1b72ac8d337514d331',1,'starpu_codelet']]],
  ['cuda_5ffuncs',['cuda_funcs',['../group__API__Codelet__And__Tasks.html#aa6a8436117176270c5372d4dfb006a1f',1,'starpu_codelet']]],
  ['cuda_5fopengl_5finteroperability',['cuda_opengl_interoperability',['../group__API__Initialization__and__Termination.html#adeb1e95a62549f3ef436bbf13cf30e0a',1,'starpu_conf']]],
  ['cuda_5fto_5fcpu_5fcl',['cuda_to_cpu_cl',['../group__API__Data__Interfaces.html#ad3669cbe8a1a2cb874f86b3b74d9731f',1,'starpu_multiformat_data_interface_ops']]],
  ['cuda_5fto_5fcuda',['cuda_to_cuda',['../group__API__Data__Interfaces.html#aa6fbc9f205069f8a9d0bbcf0e9e00ab0',1,'starpu_data_copy_methods']]],
  ['cuda_5fto_5fcuda_5fasync',['cuda_to_cuda_async',['../group__API__Data__Interfaces.html#aabe802ad7ab3b1cd0c3797cb97783616',1,'starpu_data_copy_methods']]],
  ['cuda_5fto_5fopencl',['cuda_to_opencl',['../group__API__Data__Interfaces.html#a415c1c3a9382fd04069c9996c30d22c1',1,'starpu_data_copy_methods']]],
  ['cuda_5fto_5fram',['cuda_to_ram',['../group__API__Data__Interfaces.html#a19615bd5fb64e1cc1c9fce573215170c',1,'starpu_data_copy_methods']]],
  ['cuda_5fto_5fram_5fasync',['cuda_to_ram_async',['../group__API__Data__Interfaces.html#ac73d602dfd9bd07ed7c596f851897117',1,'starpu_data_copy_methods']]],
  ['current_5fidle_5ftime',['current_idle_time',['../sc__hypervisor__monitoring_8h.html#a670c50b3b52c05d3ca95e8717f1b4a6b',1,'sc_hypervisor_wrapper']]],
  ['cursor',['cursor',['../group__API__Workers__Properties.html#a3460c754c642b2244d4c2ceb98101ece',1,'starpu_sched_ctx_iterator']]],
  ['custom',['custom',['../group__API__SC__Hypervisor.html#ae3a65239bb98f10756743787df0b9319',1,'sc_hypervisor_policy']]]
];

==> mingw-w64-starpu-1.3.9-3.src.tar.gz: starpu-1.3.9/doc/doxygen/html/search/variables_2.js <==
var searchData=
[
  ['c',['c',['../group__API__Data__Interfaces.html#ad25ad86f33897a36c7197bcf80242df4',1,'starpu_bcsr_interface::c()'],['../group__API__Performance__Model.html#ac651825cdcd22fb9e6389d73c1b4f275',1,'starpu_perfmodel_regression_model::c()']]],
  ['calibrate',['calibrate',['../group__API__Initialization__and__Termination.html#ab05d39eda9e1eef89024575fcaccef23',1,'starpu_conf']]],
  ['callback_5farg',['callback_arg',['../group__API__Codelet__And__Tasks.html#aa08e84ae3bf2e88fdb893f1e123cead8',1,'starpu_task']]],
  ['callback_5farg_5ffree',['callback_arg_free',['../group__API__Codelet__And__Tasks.html#a397c52cbdde57ee5d09b7d929989ca8b',1,'starpu_task']]],
  ['callback_5fend_5ftime',['callback_end_time',['../group__API__Profiling.html#a3296b9aa5339bf99f00f5377517c2390',1,'starpu_profiling_task_info']]],
  ['callback_5ffunc',['callback_func',['../group__API__Codelet__And__Tasks.html#a5275657341967fb8d3d6a345b21d9ce0',1,'starpu_codelet::callback_func()'],['../group__API__Codelet__And__Tasks.html#a03361fd33500d78c065bbe18d4626a7a',1,'starpu_task::callback_func()']]],
  ['callback_5fstart_5ftime',['callback_start_time',['../group__API__Profiling.html#a4ad1ae7ed15ea7001b5dc8e1d9579235',1,'starpu_profiling_task_info']]],
  ['can_5fcopy',['can_copy',['../group__API__Data__Interfaces.html#a0f4028f4d2e56725de028c90696b1f7e',1,'starpu_data_copy_methods']]],
  ['can_5fexecute',['can_execute',['../group__API__Codelet__And__Tasks.html#a29800b6f7f322a5365cfdca266f421a7',1,'starpu_codelet']]],
  ['can_5fpull',['can_pull',['../group__API__Modularized__Scheduler.html#a4c7d5c03e2acf93fa737540b35eb1001',1,'starpu_sched_component']]],
  ['can_5fpush',['can_push',['../group__API__Modularized__Scheduler.html#abf315d3c1f60fbcab6a001f7925dc4fa',1,'starpu_sched_component']]],
  ['catch_5fsignals',['catch_signals',['../group__API__Initialization__and__Termination.html#ae11cad1ceafab919d348de1f00b044d1',1,'starpu_conf']]],
  ['checked',['checked',['../group__API__Codelet__And__Tasks.html#a18eb7e68348b41db1818e8307e03d5be',1,'starpu_codelet']]],
  ['children',['children',['../group__API__Modularized__Scheduler.html#a6979a86b074eb35903929f98272b2ab2',1,'starpu_sched_component']]],
  ['cl',['cl',['../group__API__OpenMP__Runtime__Support.html#a983c8209cef872e2798c2fee32012195',1,'starpu_omp_parallel_region_attr::cl()'],['../group__API__OpenMP__Runtime__Support.html#a4f4e595f12101bbace47d4748d6d3e3b',1,'starpu_omp_task_region_attr::cl()'],['../group__API__Codelet__And__Tasks.html#ac0e8ab897e436b244f13ec17b1191062',1,'starpu_task::cl()'],['../group__API__SC__Hypervisor.html#aea7e98763fa2b2f5553cc73bf29705f7',1,'sc_hypervisor_policy_task_pool::cl()']]],
  ['cl_5farg',['cl_arg',['../group__API__OpenMP__Runtime__Support.html#acd7ec3b07eded637a0c9de5df3192e87',1,'starpu_omp_parallel_region_attr::cl_arg()'],['../group__API__OpenMP__Runtime__Support.html#ad7d88a7759aade7ae379a88eb737993b',1,'starpu_omp_task_region_attr::cl_arg()'],['../group__API__Codelet__And__Tasks.html#a1d6f3af0eab3a339c550a5a55fbd7ab2',1,'starpu_task::cl_arg()']]],
  ['cl_5farg_5ffree',['cl_arg_free',['../group__API__OpenMP__Runtime__Support.html#aea66f9b4181afb2e4b4c799a09d8a4f0',1,'starpu_omp_parallel_region_attr::cl_arg_free()'],['../group__API__OpenMP__Runtime__Support.html#ad64a8be227ee0a2c4ea8fa2eca3d20c0',1,'starpu_omp_task_region_attr::cl_arg_free()'],['../group__API__Codelet__And__Tasks.html#a3da11609ab9c508bb753cae1b2d8f24f',1,'starpu_task::cl_arg_free()']]],
  ['cl_5farg_5fsize',['cl_arg_size',['../group__API__OpenMP__Runtime__Support.html#ab804599e2d1ce232830954dbdf3ed886',1,'starpu_omp_parallel_region_attr::cl_arg_size()'],['../group__API__OpenMP__Runtime__Support.html#a594489c9f845922d685046c25f5540e8',1,'starpu_omp_task_region_attr::cl_arg_size()'],['../group__API__Codelet__And__Tasks.html#adac9af88fed23241fc65259712352126',1,'starpu_task::cl_arg_size()']]],
  ['close',['close',['../group__API__Out__Of__Core.html#a00b4fbe01a33b0f2526bd70e8128dfbd',1,'starpu_disk_ops']]],
  ['coeff',['coeff',['../group__API__Performance__Model.html#aec35b7054c3d28730425f47c61b8a297',1,'starpu_perfmodel_regression_model']]],
  ['colind',['colind',['../group__API__Data__Interfaces.html#a41630100e7fb39af8bec44fd57a559c0',1,'starpu_csr_interface::colind()'],['../group__API__Data__Interfaces.html#a52dd5cb526a5a1114b2c6737e9da7d1c',1,'starpu_bcsr_interface::colind()']]],
  ['color',['color',['../group__API__Codelet__And__Tasks.html#ad6dfcbb8bb86ca8ce0678b4b10bf853b',1,'starpu_codelet::color()'],['../group__API__Codelet__And__Tasks.html#ab96604deeb87e2924df311c9b5a7d303',1,'starpu_task::color()']]],
  ['columns',['columns',['../group__API__Data__Interfaces.html#ac01fd0c59e0a5740ab8b000a2681f0aa',1,'starpu_coo_interface']]],
  ['combinations',['combinations',['../group__API__Performance__Model.html#a4fc15e27386dcbfbe0bba81f917ce198',1,'starpu_perfmodel']]],
  ['compare',['compare',['../group__API__Data__Interfaces.html#a79dbc0a279510b9daacfa82248cc3f09',1,'starpu_data_interface_ops']]],
  ['compute_5fidle',['compute_idle',['../sc__hypervisor__monitoring_8h.html#abf552a3af2c6928c9f4e0dd6e845c7e0',1,'sc_hypervisor_wrapper']]],
  ['compute_5fpartial_5fidle',['compute_partial_idle',['../sc__hypervisor__monitoring_8h.html#a1e0e2c4e5a03176a09fe4f84a4b5a1ee',1,'sc_hypervisor_wrapper']]],
  ['config',['config',['../sc__hypervisor__monitoring_8h.html#a7ed3efcd3b7e2886f5610e5f5920eb99',1,'sc_hypervisor_wrapper']]],
  ['consider_5fmax',['consider_max',['../sc__hypervisor__monitoring_8h.html#ae60f91b9b83b82c3dd6ef43e7c8d730d',1,'sc_hypervisor_wrapper']]],
  ['copy',['copy',['../group__API__Out__Of__Core.html#a841756a748f25860e45e12e215249683',1,'starpu_disk_ops']]],
  ['copy_5fmethods',['copy_methods',['../group__API__Data__Interfaces.html#afd365e7e0abc01f07b6d7b9201c4ce22',1,'starpu_data_interface_ops']]],
  ['cost_5ffunction',['cost_function',['../group__API__Performance__Model.html#a13f34a1532294c101254beb106f124f3',1,'starpu_perfmodel_per_arch::cost_function()'],['../group__API__Performance__Model.html#a16967b7c8c6860d283fc7db434cd3c7c',1,'starpu_perfmodel::cost_function()']]],
  ['cpu_5felemsize',['cpu_elemsize',['../group__API__Data__Interfaces.html#a67a1f3202dfc2512ed7ed14bed4f3623',1,'starpu_multiformat_data_interface_ops']]],
  ['cpu_5ffunc',['cpu_func',['../group__API__Codelet__And__Tasks.html#ad5f00ed5a0a59b72c0d90d9718376893',1,'starpu_codelet']]],
  ['cpu_5ffuncs',['cpu_funcs',['../group__API__Codelet__And__Tasks.html#a593418a8961318e4085177abeeaa43ad',1,'starpu_codelet']]],
  ['cpu_5ffuncs_5fname',['cpu_funcs_name',['../group__API__Codelet__And__Tasks.html#abfc0aa8247673ad1c629d5ddd30082a3',1,'starpu_codelet']]],
  ['cpu_5fto_5fcuda_5fcl',['cpu_to_cuda_cl',['../group__API__Data__Interfaces.html#aab231ea3b842e030917eb2b67e9439eb',1,'starpu_multiformat_data_interface_ops']]],
  ['cpu_5fto_5fmic_5fcl',['cpu_to_mic_cl',['../group__API__Data__Interfaces.html#adc3e56ba90f959e6aec093ba0fa3d385',1,'starpu_multiformat_data_interface_ops']]],
  ['cpu_5fto_5fopencl_5fcl',['cpu_to_opencl_cl',['../group__API__Data__Interfaces.html#ac1103b46f4f50af4aeaa2772b3662cb2',1,'starpu_multiformat_data_interface_ops']]],
  ['cuda_5felemsize',['cuda_elemsize',['../group__API__Data__Interfaces.html#a00927819b3899892ec152968efe0b158',1,'starpu_multiformat_data_interface_ops']]],
  ['cuda_5fflags',['cuda_flags',['../group__API__Codelet__And__Tasks.html#aaa458493da38622be2713700f3c96a5d',1,'starpu_codelet']]],
  ['cuda_5ffunc',['cuda_func',['../group__API__Codelet__And__Tasks.html#a3d895b523ca1bf1b72ac8d337514d331',1,'starpu_codelet']]],
  ['cuda_5ffuncs',['cuda_funcs',['../group__API__Codelet__And__Tasks.html#aa6a8436117176270c5372d4dfb006a1f',1,'starpu_codelet']]],
  ['cuda_5fopengl_5finteroperability',['cuda_opengl_interoperability',['../group__API__Initialization__and__Termination.html#adeb1e95a62549f3ef436bbf13cf30e0a',1,'starpu_conf']]],
  ['cuda_5fto_5fcpu_5fcl',['cuda_to_cpu_cl',['../group__API__Data__Interfaces.html#ad3669cbe8a1a2cb874f86b3b74d9731f',1,'starpu_multiformat_data_interface_ops']]],
  ['cuda_5fto_5fcuda',['cuda_to_cuda',['../group__API__Data__Interfaces.html#aa6fbc9f205069f8a9d0bbcf0e9e00ab0',1,'starpu_data_copy_methods']]],
  ['cuda_5fto_5fcuda_5fasync',['cuda_to_cuda_async',['../group__API__Data__Interfaces.html#aabe802ad7ab3b1cd0c3797cb97783616',1,'starpu_data_copy_methods']]],
  ['cuda_5fto_5fopencl',['cuda_to_opencl',['../group__API__Data__Interfaces.html#a415c1c3a9382fd04069c9996c30d22c1',1,'starpu_data_copy_methods']]],
  ['cuda_5fto_5fram',['cuda_to_ram',['../group__API__Data__Interfaces.html#a19615bd5fb64e1cc1c9fce573215170c',1,'starpu_data_copy_methods']]],
  ['cuda_5fto_5fram_5fasync',['cuda_to_ram_async',['../group__API__Data__Interfaces.html#ac73d602dfd9bd07ed7c596f851897117',1,'starpu_data_copy_methods']]],
  ['current_5fidle_5ftime',['current_idle_time',['../sc__hypervisor__monitoring_8h.html#a670c50b3b52c05d3ca95e8717f1b4a6b',1,'sc_hypervisor_wrapper']]],
  ['cursor',['cursor',['../group__API__Workers__Properties.html#a3460c754c642b2244d4c2ceb98101ece',1,'starpu_sched_ctx_iterator']]],
  ['custom',['custom',['../group__API__SC__Hypervisor.html#ae3a65239bb98f10756743787df0b9319',1,'sc_hypervisor_policy']]]
];
